Example code:

```
from oyunlayiciapi import Oyunlayici
ip = Oyunlayici.serverIp("mc.traplegacy.com")
print(ip)
```

What you can use?
Oyunlayici.isOnline/serverIp/playersMax/playersOnline/serverVersion/serverProtocol/queryPing

Output:
45.141.150.220